@@ -168,7 +168,7 @@ class TOWTModel(Model):
             unocc_model = LinearRegression().fit(unocc_x_train, unocc_y_train)
             self.unocc_model = unocc_model
 
-        
+        '''
         occ_model, occ_train = model_and_predict(train=train, occupied=True)
         # Unoccupied model
         unocc_model = None
@@ -191,8 +191,8 @@ class TOWTModel(Model):
                   'knot_temps': (knot_temps, used_knot_temps),
                   'metrics': metrics}
         return(output)
-        
-        #return(main)
+        '''
+        return(main)
 
     def predict(self, df, occ_model=None, unocc_model=None):
         """
